@@ -1,4 +1,4 @@
-from b_lambda_layer_common.source.python.b_lambda_layer_common.util.logging import LoggingManager
+from b_lambda_layer_common.util.logging import LoggingManager
 
 
 def test_FUNC_setup_logging_WITH_nothing_EXPECT_logging_successfully_set_up() -> None:
